// ********* YAMAHA THR10 Pedalboard **********
// *             Preset 1 to 5                *
// *             Tuner (single press)         *
// *             AMP selector (UP and DOWN)   *
// *             Loop Fading Function         *
// *             OLED Display                 *
// ********************************************
 

#include <SoftwareSerial.h> 
SoftwareSerial SoftSerial(12, 11); // RX, TX  11 nano Pedalboard -> 5 nano THR10
                                   //         12 nano Pedalboard -> 6 nano THR10

#include <SPI.h>                   // OLED library
#include <Wire.h>                  // OLED
#include <Adafruit_GFX.h>
#include <Adafruit_SSD1306.h>
#include <Fonts/FreeSans24pt7b.h>
#include <Fonts/FreeSans18pt7b.h>
#include <Fonts/FreeSans9pt7b.h>

#define SCREEN_WIDTH 128           // OLED display width, in pixels
#define SCREEN_HEIGHT 64           // OLED display height, in pixels

// Declaration for an SSD1306 display connected to I2C (SDA, SCL pins)
#define OLED_RESET     -1 // Reset pin # (or -1 if sharing Arduino reset pin)
Adafruit_SSD1306 display(SCREEN_WIDTH, SCREEN_HEIGHT, &Wire, OLED_RESET);
                                   

int switch0 = 0;     // Tuner             
int switch1 = 0;     // Preset 1
int switch2 = 0;     // Preset 2
int switch3 = 0;     // Preset 3
int switch4 = 0;     // Preset 4
int switch5 = 0;     // Preset 5
int switchUp = 0;    // UP
int switchDown = 0;  // DOWN
int switchFade = 0;  // FADE

byte T = 2;      // switch 0 (Tuner)
byte A = 3;      // switch 1 (Preset)
byte B = 4;      // switch 2 (Preset)
byte C = 5;      // switch 3 (Preset)
byte D = 6;      // switch 4 (Preset)
byte E = 7;      // switch 5 (Preset)
byte F = 8;      // switch UP (Select)
byte G = 9;      // switch DOWN (Select)
byte H = 10;     // switch FADE (Select)

char *textTop[] = {"YAMAHA", "TUNER" , "PRESET", "MOD", "  UP", " DOWN" , "MANUAL" };
char *textMid[] = {"   THR10     " , "   YAMAHA   " , "YAMAHA THR" };
char *textBottom[] = {"T", "1", "2", "3", "4", "5" , ">" , " <" , " >" , "<" , "Y" , "Fading" };
int tTop = 0;
int tMid = 0;
int tBottom = 10;
int x = 80;
int y = 65;
int del = 250;


//Paste your bitmap here

// '', 128x64px
const unsigned char myBitmap [] PROGMEM = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x1f, 0xff, 0xff, 0xff, 0xfe, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x1f, 0xff, 0xff, 0xff, 0xff, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x0f, 0xff, 0xff, 0xff, 0xff, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x0f, 0xff, 0xff, 0xff, 0xff, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x07, 0xff, 0xff, 0xff, 0xff, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0f, 0xff, 0xff, 0xfc, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x1f, 0xff, 0xc0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x7f, 0xf7, 0xf0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x7f, 0xff, 0xec, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0xff, 0xef, 0x77, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x04, 0x00, 0x03, 0x7e, 0x7c, 0x69, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x04, 0x00, 0x06, 0x0d, 0x80, 0x77, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x04, 0x00, 0x02, 0x00, 0x81, 0xf3, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x06, 0x00, 0x08, 0x00, 0x00, 0x17, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x06, 0x00, 0x08, 0x00, 0x02, 0x02, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x07, 0xc0, 0x04, 0x02, 0x08, 0x04, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x07, 0xc0, 0x00, 0x17, 0x80, 0x81, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x07, 0xc0, 0x05, 0xff, 0xfe, 0x83, 0xc0, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x07, 0xd0, 0x13, 0xff, 0xff, 0xc3, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x05, 0xf0, 0x13, 0xff, 0xff, 0xc0, 0x20, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x05, 0xf0, 0x13, 0xff, 0xff, 0xe0, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x05, 0xf0, 0x13, 0xff, 0xff, 0xe0, 0x20, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x05, 0xf0, 0x03, 0xff, 0xff, 0xe0, 0x70, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x05, 0xf0, 0x07, 0xff, 0xff, 0xe0, 0x21, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x01, 0xf0, 0x00, 0x0f, 0xff, 0xf0, 0x20, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x05, 0xf0, 0x08, 0x01, 0x81, 0xf0, 0x20, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x05, 0xf0, 0x20, 0x00, 0x00, 0x70, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x05, 0xf0, 0x30, 0x00, 0x00, 0x00, 0x24, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x05, 0xf0, 0x30, 0x00, 0x00, 0x00, 0x54, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x05, 0xf0, 0x30, 0x01, 0x00, 0x00, 0xf7, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x01, 0xf0, 0x30, 0x03, 0x80, 0x01, 0xf5, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x01, 0xf0, 0x10, 0x07, 0x80, 0x08, 0xf4, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x01, 0xf0, 0x18, 0x07, 0x80, 0x19, 0xb0, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x01, 0xf0, 0x1f, 0x9f, 0xc0, 0x18, 0xf0, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x01, 0xf0, 0x1f, 0xff, 0x40, 0x3c, 0xb0, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x01, 0xf0, 0x1f, 0xf6, 0x1f, 0xfd, 0xb0, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x01, 0xf0, 0x0f, 0xfc, 0x3f, 0xff, 0xb0, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x01, 0xf1, 0x87, 0xfd, 0x3f, 0xf7, 0xb0, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x01, 0xf0, 0x07, 0xe0, 0xff, 0xff, 0xf2, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x01, 0xf1, 0x87, 0x80, 0x3f, 0xf9, 0xf2, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x01, 0xf0, 0x07, 0xf8, 0x1f, 0xf0, 0xb2, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x01, 0xf1, 0x83, 0xfe, 0x0e, 0xf9, 0xb2, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x07, 0xf0, 0x03, 0xfd, 0xef, 0xfb, 0xb0, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x01, 0xb1, 0xc1, 0xff, 0xff, 0xff, 0xff, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x01, 0xb0, 0x00, 0xff, 0xff, 0xe1, 0x92, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x01, 0xb1, 0x80, 0xff, 0xe7, 0xe3, 0xd2, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x01, 0xb0, 0x00, 0xff, 0xc1, 0xe1, 0xd2, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x01, 0xf1, 0x80, 0xff, 0x01, 0xf3, 0x92, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x01, 0xf0, 0x03, 0xfc, 0x03, 0xfb, 0x92, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x01, 0xf1, 0x3f, 0xff, 0x6f, 0xff, 0x92, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x01, 0xb0, 0x7f, 0xff, 0xff, 0xfe, 0x92, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x01, 0xb0, 0x0f, 0xff, 0xff, 0xfe, 0x22, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x01, 0xbf, 0xff, 0xff, 0xff, 0xfe, 0x02, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x01, 0xbf, 0xfe, 0x7f, 0xff, 0xfc, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x01, 0xff, 0xf8, 0xff, 0xff, 0xf8, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x01, 0xff, 0xe1, 0xff, 0xfd, 0xf0, 0x00, 0xc0, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x01, 0xff, 0x81, 0xff, 0xff, 0xe0, 0x00, 0x60, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x07, 0xfe, 0x01, 0xff, 0xff, 0xc0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x07, 0xf0, 0x00, 0xff, 0xff, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x07, 0xe0, 0x00, 0xff, 0xfe, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x07, 0xc0, 0x00, 0xff, 0xf8, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x07, 0x00, 0x00, 0x7f, 0xe0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x07, 0x00, 0x00, 0x1f, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x06, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
};


void setup() 

{
    pinMode(LED_BUILTIN, OUTPUT);
    pinMode(T, INPUT);
    pinMode(A, INPUT);
    pinMode(B, INPUT);
    pinMode(C, INPUT);
    pinMode(D, INPUT);
    pinMode(E, INPUT);
    pinMode(F, INPUT);
    pinMode(G, INPUT);
    pinMode(H, INPUT);
    
    SoftSerial.begin(9600);
    SoftSerial.print("1");     // to initialize the communication
   // Serial.begin(9600);  
   // Serial.println("YAMAHA PEDALBOARD START");

      // SSD1306_SWITCHCAPVCC = generate display voltage from 3.3V internally
  if(!display.begin(SSD1306_SWITCHCAPVCC, 0x3C)) { // Address 0x3C for 128x64
    Serial.println(F("SSD1306 allocation failed"));
    for(;;);      // Don't proceed, loop forever
  }

      // Clear the buffer
  display.clearDisplay();

  display.drawBitmap(0, 0, myBitmap, 128, 64, WHITE); // display.drawBitmap(x position, y position, bitmap data, bitmap width, bitmap height, color)
  display.display();


}



void loop() {
              switch0 = digitalRead(T);
              switch1 = digitalRead(A);
              switch2 = digitalRead(B);
              switch3 = digitalRead(C);
              switch4 = digitalRead(D);
              switch5 = digitalRead(E);
              switchUp = digitalRead(F);
              switchDown = digitalRead(G);
              switchFade = digitalRead(H);

  if (switch0 == HIGH) {

     SoftSerial.print("0");
     digitalWrite(LED_BUILTIN, HIGH);
    // Serial.println("TUNER");
       tTop = 1;
       tMid = 0;
       tBottom = 0;
       text();
     delay(del);             }
  
   if (switch1 == HIGH) {

     SoftSerial.print("1");
     digitalWrite(LED_BUILTIN, LOW);
    // Serial.println("1");
       tTop = 2;
       tMid = 1;
       tBottom = 1;
       text();
     delay(del);             } 

  if (switch2 == HIGH) {

     SoftSerial.print("2");
     digitalWrite(LED_BUILTIN, HIGH);
    // Serial.println("2");
       tTop = 2;
       tMid = 1;
       tBottom = 2;
       text();
       delay(del);             }
  
   if (switch3 == HIGH) {

     SoftSerial.print("3");
     digitalWrite(LED_BUILTIN, LOW);
    // Serial.println("3");
       tTop = 2;
       tMid = 1;
       tBottom = 3;
       text();
     delay(del);             } 

  if (switch4 == HIGH) {

     SoftSerial.print("4");
     digitalWrite(LED_BUILTIN, HIGH);
    // Serial.println("4");
       tTop = 2;
       tMid = 1;
       tBottom = 4;
       text();
     delay(del);             }
  
   if (switch5 == HIGH) {

     SoftSerial.print("5");
     digitalWrite(LED_BUILTIN, LOW);
    // Serial.println("5");
       tTop = 2;
       tMid = 1;
       tBottom = 5;
       text();
     delay(del);             } 

  if (switchUp == HIGH) {

     SoftSerial.print("U");
     digitalWrite(LED_BUILTIN, HIGH);
    // Serial.println("UP");
       tTop = 4;
       tMid = 0;
       x = 55;
       y = 34;
       tBottom = 6;
       textover();
     delay(del);
       tTop = 6;
       tMid = 0;
       tBottom = 8;
       textover();
                               }
  
   if (switchDown == HIGH) {

     SoftSerial.print("D");
     digitalWrite(LED_BUILTIN, LOW);
    // Serial.println("DOWN");
       tTop = 5;
       tMid = 0;
       x = 35;
       y = 34;
       tBottom = 7;
       textover();
     delay(del);            
       tTop = 6;
       tMid = 0;
       tBottom = 9;
       textover();                   
                              } 

   if (switchFade == HIGH) {

     SoftSerial.print("6");
     delay(del); 
     digitalWrite(LED_BUILTIN, HIGH);
    // Serial.println("FADE");
       tTop = 7;
       tMid = 2;
       tBottom = 11;
       fade();
     delay(del);             } 


}

void text(void) {
  display.clearDisplay();
  display.stopscroll();
  display.setTextSize(1);             // Normal 1:1 pixel scale
  display.setTextColor(SSD1306_WHITE);        // Draw YELLOW text
  display.setFont();
  display.setCursor(49,0);             // Start at top-left corner +49
  display.println(textTop[tTop]);

  display.setTextColor(SSD1306_BLACK, SSD1306_WHITE); // Draw 'inverse' text
  display.setCursor(31,9);             // Start at top-left corner +31,-9
  display.println(textMid[tMid]);

  display.setTextSize(1);             // Draw 1X-scale text
  display.setTextColor(SSD1306_WHITE);
  display.setFont(&FreeSans24pt7b);
  display.setCursor(53,55);
  display.println(textBottom[tBottom]);

  display.display();
  delay(20);

}

void textover(void) {
  display.clearDisplay();         
  display.stopscroll();
  display.setTextSize(1);             // Normal 1:1 pixel scale
  display.setFont();
  display.setTextColor(SSD1306_BLACK, SSD1306_WHITE); // Draw 'inverse' text
  display.setCursor(25,0);             // Start at top-left corner +25
  display.println("               ");
  
  display.setTextColor(SSD1306_BLACK, SSD1306_WHITE); // Draw 'inverse' text
    
  display.setCursor(49,0);             // Start at top-left corner +49
  display.println(textTop[tTop]);

  display.setTextColor(SSD1306_BLACK, SSD1306_WHITE); // Draw 'inverse' text
  display.setCursor(31,9);             // Start at top-left corner +31,-9
  display.println(textMid[tMid]);

  display.setTextSize(4);             // Draw 2X-scale text
  display.setTextColor(SSD1306_WHITE);
  //   display.setFont(&FreeSans24pt7b);
  display.setCursor(x,y);
  display.println(textBottom[tBottom]);

  display.display();
  delay(20);

}


void fade(void) {

  display.clearDisplay();

  display.setTextSize(1);                     // Normal 1:1 pixel scale
  display.setTextColor(SSD1306_WHITE);        // Draw YELLOW text
  display.setFont(&FreeSans9pt7b);
  display.setCursor(0,15);                    // Start at top-left corner -15
  display.println(textMid[tMid]);
  display.setTextSize(1);                     // Draw 1X-scale text
  display.setTextColor(SSD1306_WHITE);
  display.setFont(&FreeSans18pt7b);
  display.setCursor(0,49);
  display.println(textBottom[tBottom]);

  display.display();
  delay(20);
  display.startscrollleft(0x00, 0x0F);                     // scroll text 

                 }
